from datetime import datetime
from elasticsearch import Elasticsearch
from fastapi import FastAPI, UploadFile
import httpx

es = Elasticsearch('http://elastic:9200')

app = FastAPI()

@app.get("/search/{name}")
async def search(name: str):
    occurs = list()
    resp = es.search(index="test-index", query={"simple_query_string": {"fields": ["text"], "query": name}})
    print("Got %d Hits:" % resp['hits']['total']['value'])
    for hit in resp['hits']['hits']:
        occurs.append(hit["_source"]["file"])
        print("%(author)s: %(file)s " % hit["_source"])
    return {"itens": f"{occurs}"}


@app.post("/uploadFile")
async def upload_file(file: UploadFile):
    doc = {
        'author': 'jonhleno',
        'file': f"{file.filename}",
        'text': f"{file.file.read()}",
        'timestamp': datetime.now(),
    }
    resp = es.index(index="test-index", document=doc)
    es.indices.refresh(index="test-index")
    print(resp['result'])
    return {"filename": file.filename}


@app.put("/uploadFileOwncloud")
async def upload_file_owncloud(file: UploadFile):
    files = {'upload-file': (file.filename, file.file.read(), 'text/plain')}
    headers = [(b"OCS-APIRequest", b"true")]
    http_client = httpx.Client(verify=False)
    r = http_client.put(f"http://cloud/{file.filename}", auth=('admin', 'geforce2MX'), files=files, headers=headers)
    return {"filename": file.filename}

# @app.get("/searchOwncloud/{name}")
# async def search_owncloud(name: str):
#     headers = [(b"OCS-APIRequest", b"true")]
#     search = f'<?xml version="1.0" encoding="UTF-8"?><oc:search-files xmlns:a="DAV:" xmlns:oc="http://owncloud.org/ns"><oc:search><d:displayname>{name}</d:displayname></oc:search></oc:search-files>'
#     http_client = httpx.Client(verify=False)
#     r = http_client.request(method="REPORT", url=f"https://cloud.jonhleno.net.br/dav/files/admin", auth=('admin', 'geforce2MX'), data=search, headers=headers)
#     print(r.text)
#     return {"itens"}

@app.get("/searchOwncloud/{name}")
async def searchOwncloud(name: str):
    occurs = list()
    resp = es.search(index="oc-och4ckb4z6jt", query={"simple_query_string": {"fields": ["file.content"], "query": name}})
    print("Got %d Hits:" % resp['hits']['total']['value'])
    for hit in resp['hits']['hits']:
        occurs.append(hit["_source"]["name"])
        print("%(name)s" % hit["_source"])
    return {"itens": f"{occurs}"}

